Constants
=========

Event Types
-----------

Mapped JavaScript event types to more manageable elements for analysis.

.. autoclass:: pywib.constants.EventTypes
   :members:
   :undoc-members:
   :no-index:
   :member-order: bysource

Component Types
---------------

.. autoclass:: pywib.constants.ComponentTypes
   :members:
   :undoc-members:
   :no-index:
   :member-order: bysource

DataFrame Columns
------------------

.. autoclass:: pywib.constants.ColumnNames
   :members:
   :undoc-members:
   :no-index:
   :member-order: bysource

  